.set_vc: Set the parameters of the random effect covariance matrix
Description
Set the parameters of the random effect covariance matrix
Usage
.set_vc(obj, val, as.theta = FALSE)
Arguments
as.theta
The input is given according to the reparameterization used by tramTMB
Value
A new list of parameters with updated beta part