The function only returns the correlation matrices that belong to actual
random effects (defined for groups in the data) and ignores the random
effects parameters of the smooth shift terms. To extract these, the user
should use varcov with full = TRUE.
Note that, by default, print.VarCorr.tramME prints the
standard deviations of the random effects, similarly to lme4.