A general function to define and fit tramME models.
tramME(
formula,
data,
subset,
weights,
offset,
na.action,
tram = NULL,
call = NULL,
ctm = NULL,
smooth = NULL,
negative = NULL,
silent = TRUE,
resid = FALSE,
do_update = FALSE,
estinit = TRUE,
initpar = NULL,
fixed = NULL,
nofit = FALSE,
control = optim_control(),
...
)A formula describing the model. Smooth additive terms are
defined the way as in mgcv, and random effects consistently with
the notation used in lme4.
an optional data frame, list or environment (or object
coercible by as.data.frame to a data frame) containing the
variables in the model. If not found in data, the
variables are taken from environment(formula).
an optional vector specifying a subset of observations to be used in the fitting process.
an optional vector of case weights to be used in the fitting
process. Should be NULL or a numeric vector. If present,
the weighted log-likelihood is maximised.
this can be used to specify an _a priori_ known component to
be included in the linear predictor during fitting. This
should be NULL or a numeric vector of length equal to the
number of cases.
a function which indicates what should happen when the data
contain NAs. The default is set to na.omit.
Parameter vector for the tram model type.
The original function call (to be passed from the wrapper).
A model object of the ctm class that descibes the
fixed-effects part of the tramME model.
A tramME_smooth object that describes the smooth
additive elements of the tramME model.
Logical; if TRUE, the model is parameterized with
negative coefficinets for the elements of the linear predictor.
Logical. Make TMB functionality silent.
Logical. If TRUE, the score residuals are also calculated.
This comes with some performance cost.
Logical. If TRUE, the model is set up so that the weights and the
offsets are updateable. This comes with some performance cost.
Logical. Estimate a vector of initial values for the fixed effects parameters from a (fixed effects only) mlt model
Named list of initial parameter values, if NULL, it is ignored
a named vector of fixed regression coefficients; the names need to correspond to column names of the design matrix
logical, if TRUE, creates the model object, but does not run the optimization
list with controls for optimization
Optional arguments to tram
Typically, the tramME function shouldn't be called directly; it is
only exported to allow the advanced users to define their tramME
models in a more flexible way from their basic building blocks.
The specific model functions (LmME,
BoxCoxME, ColrME, etc.) are
wrappers around this function.
For a general description of the transformation model family, see Hothorn et al. (2018), for details on the mixed-effects extension, see Tamasi and Hothorn (2021).
Hothorn, Torsten, Lisa Möst, and Peter Bühlmann. "Most Likely Transformations." Scandinavian Journal of Statistics 45, no. 1 (March 2018): 110–34. <doi:10.1111/sjos.12291>
Tamasi, Balint, and Torsten Hothorn. "tramME: Mixed-Effects Transformation Models Using Template Model Builder." The R Journal 13, no. 2 (2021): 398–418. <doi:10.32614/RJ-2021-075>